@@ -28,7 +28,7 @@ class Dispatcher(object):
         self,
         devices: List[Tuple[str, Any]],
         handlers: List[Callable[..., None]],
-        interval: float = 0.01,
+        interval: float,
     ) -> None:
         self.devices = devices
         self.handlers = handlers
@@ -54,4 +54,4 @@ class Dispatcher(object):
                 for handler in self.handlers:
                     handler(**variables)
         except StopIteration:
-            print('Stopped by handler')
+            print('Stopped by handler.')
